@@ -482,7 +482,7 @@ impl RpcClient {
         &self,
         config: RpcBlockProductionConfig,
     ) -> RpcResult<RpcBlockProduction> {
-        self.send(RpcRequest::GetBlockProduction, json!(config))
+        self.send(RpcRequest::GetBlockProduction, json!([config]))
     }
 
     pub fn get_stake_activation(
@@ -2162,6 +2162,7 @@ mod tests {
         let signature = rpc_client.send_transaction(&tx);
         assert!(signature.is_err());
     }
+
     #[test]
     fn test_get_recent_blockhash() {
         let rpc_client = RpcClient::new_mock("succeeds".to_string());
@@ -2176,6 +2177,20 @@ mod tests {
         assert!(rpc_client.get_recent_blockhash().is_err());
     }
 
+    #[test]
+    fn test_custom_request() {
+        let rpc_client = RpcClient::new_mock("succeeds".to_string());
+
+        let slot = rpc_client.get_slot().unwrap();
+        assert_eq!(slot, 0);
+
+        let custom_slot = rpc_client
+            .send::<Slot>(RpcRequest::Custom { method: "getSlot" }, Value::Null)
+            .unwrap();
+
+        assert_eq!(slot, custom_slot);
+    }
+
     #[test]
     fn test_get_signature_status() {
         let signature = Signature::default();
@@ -2230,4 +2245,23 @@ mod tests {
         let rpc_client = RpcClient::new_mock("succeeds".to_string());
         thread::spawn(move || rpc_client);
     }
+
+    // Regression test that the get_block_production_with_config
+    // method internally creates the json params array correctly.
+    #[test]
+    fn get_block_production_with_config_no_error() -> ClientResult<()> {
+        let rpc_client = RpcClient::new_mock("succeeds".to_string());
+
+        let config = RpcBlockProductionConfig {
+            identity: None,
+            range: None,
+            commitment: None,
+        };
+
+        let prod = rpc_client.get_block_production_with_config(config)?.value;
+
+        assert!(!prod.by_identity.is_empty());
+
+        Ok(())
+    }
 }
