@@ -86,6 +86,9 @@ pub enum RpcRequest {
     SendTransaction,
     SimulateTransaction,
     SignVote,
+    Custom {
+        method: &'static str,
+    },
 }
 
 #[allow(deprecated)]
@@ -154,6 +157,7 @@ impl fmt::Display for RpcRequest {
             RpcRequest::SendTransaction => "sendTransaction",
             RpcRequest::SimulateTransaction => "simulateTransaction",
             RpcRequest::SignVote => "signVote",
+            RpcRequest::Custom { method } => method,
         };
 
         write!(f, "{}", method)
